translate.tools.podebug

Package translate :: Package tools :: Module podebug |
[hide private]
[frames] | no frames]

# Module podebug

source code

Insert debug messages into XLIFF and Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/podebug for examples and usage instructions.

Classes | [hide private]
| podebug

Functions | [hide private]
add_prefix(prefix, stringelems) | source code
convertpo(inputfile, outputfile, templatefile, format=None, rewritestyle=None, ignoreoption=None) Reads in inputfile, changes it to have debug strings, writes to outputfile. | source code
main() | source code

Variables | [hide private]
| podebug_parsers = ``[`<bound method type.regex_parse of <class 't`...``

Imports: os, re, hash, factory, StringElem, general, rich_parse, dtd2po

Variables Details | [hide private]

  ### podebug_parsers Value:
      [<bound method type.regex_parse of <class 'translate.storage.placeable
      s.general.NewlinePlaceable'>>,
       <bound method type.regex_parse of <class 'translate.storage.placeable
      s.general.XMLTagPlaceable'>>,
       <bound method type.regex_parse of <class 'translate.storage.placeable
      s.general.AltAttrPlaceable'>>,
       <bound method type.regex_parse of <class 'translate.storage.placeable
      s.general.XMLEntityPlaceable'>>,
      ...